inpatient_group_dict = {
    "최고도": "A1",
    "고도": "A2",
    "중도": "A3",
    "경도": "A6",
    "선택입원": "A7",
}

ldl_description_dict = {
    "ldl_a10_a": "담배를 피우는지 여부 (0: 아니오, 1: 예)",
    "ldl_a10_b": "술을 자주 마시는지 여부 (0: 아니오, 1: 예)",
    "ldl_a10_c": "운동(주4일이상, 30분이상)여부 (0: 아니오, 1: 예)",
    "ldl_a10_d": "식사(하루 세끼) 챙겨먹는지 여부 (0: 아니오, 1: 예)",
    "ldl_a11": "장기요양등급 및 신청 (1: 해당없음, 2: 미신청, 3: 신청중, 4: 신청하였으나 인정 못 받음, 5: 등급 내자, 6: 등급 외자)",
    "ldl_a12_a": "장기요양등급 (1: 1등급, 2: 2등급, 3: 3등급, 4: 4~5등급, 5: 인지지원등급, 6: 확인불가)",
    "ldl_a12_b1": "장기요양이용서비스-1. 주야간보호 (0: 미선택, 1: 선택)",
    "ldl_a12_b2": "장기요양이용서비스-2. 방문요양 (0: 미선택, 1: 선택)",
    "ldl_a12_b3": "장기요양이용서비스-3. 방문간호 (0: 미선택, 1: 선택)",
    "ldl_a12_b4": "장기요양이용서비스-4. 방문목욕 (0: 미선택, 1: 선택)",
    "ldl_a12_b5": "장기요양이용서비스-5. 단기보호 (0: 미선택, 1: 선택)",
    "ldl_a12_b6": "장기요양이용서비스-6. 복지용구 구입 및 대여 (0: 미선택, 1: 선택)",
    "ldl_a12_b7": "장기요양이용서비스-7. 시설입소 (0: 미선택, 1: 선택)",
    "ldl_a12_b8": "장기요양이용서비스-8. 기타 (0: 미선택, 1: 선택)",
    "ldl_a13": "장기요양서비스 이용의향 (0: 아니오, 1: 예)",
    "ldl_a14_a": "사회환경선별조사-응답거부 (0: 거부안함, 1: 거부)",
    "ldl_a14_b": "사회환경선별조사-식사준비, 청소 등의 도움을 줄 수 있는 사람이 없는지 여부 (0: 아니오, 1: 예)",
    "ldl_a14_c": "사회환경선별조사-전기,수도 등 공과금 미납으로 서비스 중단 고지를 받은 적이 있는지 여부 (0: 아니오, 1: 예)",
    "ldl_a14_d": "사회환경선별조사-안정적으로 거주할 집이 없어 노숙을 한 적이 있는지 여부 (0: 아니오, 1: 예)",
    "ldl_a14_e": "사회환경선별조사-병원비, 월세, 주거비, 난방비 등 비용 지불이 어려운 적이 있는지 여부 (0: 아니오, 1: 예)",
    "ldl_a14_f": "사회환경선별조사-교통수단 부족으로 진료, 복지관 등 외출이 어려웠던 적이 있는지 여부 (0: 아니오, 1: 예)",
    "ldl_a14_g": "사회환경선별조사-먹을 것이 없거나, 학대를 받는 등 긴급하게 도움이 필요한 적이 있는지 여부 (0: 아니오, 1: 예)",
    "ldl_b1": "혼수 (0: 아니오, 1: 예)",
    "ldl_b2": "섬망 (0: 없음, 1: 섬망 증상이 있으나, 지난 7일 이전에 발생함, 2: 섬망 증상이 있으나, 지난 7일 이내에 발생하였거나 악화되고 있음)",
    "ldl_c1": "단기기억력장애 (0: 정상, 1: 이상 있음, 2: 확인 불가)",
    "ldl_c2": "일상 생활사에 관해 의사결정을 할 수 있는 인식기술 (0: 스스로 일관성 있고 합리적인 의사결정을 함, 1: 새로운 상황에서만 의사결정의 어려움 있음, 2: 인식기술이 다소 손상됨, 3: 인식기술이 심하게 손상됨)",
    "ldl_c3": "이해시키는 능력 (0: 이해시킴, 1: 대부분 이해시킴, 2: 가끔 이해시킴, 3: 거의/전혀 이해시키지 못함)",
    "ldl_c4": "말로 의사표현을 할 수 있음 (0: 아니오, 1: 예)",
    "ldl_c5_a": "행동심리증상 빈도 a.망상 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_b": "행동심리증상 빈도 b.환각 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_c": "행동심리증상 빈도 c.초조/공격성 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_d": "행동심리증상 빈도 d.우울/낙담 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_e": "행동심리증상 빈도 e.불안 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_f": "행동심리증상 빈도 f.들뜬 기분/다행감 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_g": "행동심리증상 빈도 g.무감동/무관심 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_h": "행동심리증상 빈도 h.탈억제 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_i": "행동심리증상 빈도 i.과민/불안정 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_j": "행동심리증상 빈도 j.이상 운동증상 또는 반복적 행동 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_k": "행동심리증상 빈도 k.수면/야간행동 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_l": "행동심리증상 빈도 l.식욕/식습관의 변화 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_m": "행동심리증상 빈도 m.케어에 대한 저항 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_n": "행동심리증상 빈도 n.배회 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c6_a": "K-MMSE 검사 실시여부 (0: 아니오, 1: 예)",
    "ldl_c6_b1": "K-MMSE 점수 (0-99)",
    "ldl_c6_b2": "K-MMSE 검사일 (YYYYMMDD)",
    "ldl_c7_a": "CDR 검사 실시여부 (0: 아니오, 1: 예)",
    "ldl_c7_b1": "CDR 점수 (0-9.9)",
    "ldl_c7_b2": "CDR 검사일 (YYYYMMDD)",
    "ldl_c7_c": "GDS 검사 실시여부 (0: 아니오, 1: 예)",
    "ldl_c7_d1": "GDS 점수 (0-9)",
    "ldl_c7_d2": "GDS 검사일 (YYYYMMDD)",
    "ldl_d1": "일상생활 활동 능력 1. 옷 벗고 입기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d2": "일상생활 활동 능력 2. 세수하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d3": "일상생활 활동 능력 3. 양치질하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d4": "일상생활 활동 능력 4. 목욕하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d5": "일상생활 활동 능력 5. 식사하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d6": "일상생활 활동 능력 6. 체위 변경하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d7": "일상생활 활동 능력 7. 일어나 앉기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d8": "일상생활 활동 능력 8. 옮겨 앉기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d9": "일상생활 활동 능력 9. 방 밖으로 나오기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d10": "일상생활 활동 능력 10. 화장실 사용하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d11": "와상상태 여부 (0: 아니오, 1: 예)",
    "ldl_d12_a": "해당 없음",
    "ldl_d12_b": "해당 없음",
    "ldl_d12_c": "해당 없음",
    "ldl_e1": "대변조절 상태 (0: 조절할 수 있음, 1: 가끔 실금함, 2: 자주 실금함, 3. 조절 못함)",
    "ldl_e2": "소변조절 상태 (0: 조절할 수 있음, 1: 가끔 실금함, 2: 자주 실금함, 3. 조절 못함)",
    "ldl_e3_a": "배변 조절 기구 및 프로그램 a. 일정하게 짜여진 배뇨계획 (0: 미선택, 1: 선택)",
    "ldl_e3_b": "배변 조절 기구 및 프로그램 b. 방광 훈련 프로그램 (0: 미선택, 1: 선택)",
    "ldl_e3_c": "배변 조절 기구 및 프로그램 c. 규칙적 도뇨 (0: 미선택, 1: 선택)",
    "ldl_e3_d": "배변 조절 기구 및 프로그램 d. 외부(콘돔형) 카테터 (0: 미선택, 1: 선택)",
    "ldl_e3_e": "배변 조절 기구 및 프로그램 e. 패드, 팬티형 기저귀 (0: 미선택, 1: 선택)",
    "ldl_e3_f": "배변 조절 기구 및 프로그램 f. 인공루 (0: 미선택, 1: 선택)",
    "ldl_e3_g": "배변 조절 기구 및 프로그램 g. 유치도뇨관 삽입 (0: 미선택, 1: 선택)",
    "ldl_e3_g1": "해당 없음",
    "ldl_e3_g1_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g1_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g2_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g2_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g3_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g3_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g4_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g4_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g5_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g5_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g6_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g6_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g7_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g7_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g8_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g8_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g9_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g9_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g10_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g10_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g11": "유치도뇨관 삽입기간(g-1 ~ g-10을 제외한 삽입기간)",
    "ldl_e3_h": "배변 조절 기구 및 프로그램 h. 해당사항 없음(0: 미선택, 1: 선택)",
    "ldl_e4": "해당 없음",
    "ldl_e4_a": "배뇨일지 작성여부 (0: 아니오, 1: 예)",
    "ldl_e4_b": "배뇨일지 작성일수",
    "ldl_f1_a": "질병 및 상해 항목 a. 당뇨 (0: 미선택, 1: 선택)",
    "ldl_f1_a1_a": "혈당검사(1일 3회 이상)매일 실시 여부 (0: 아니오, 1: 예)",
    "ldl_f1_a1_b1": "공복시 혈당 (mg/dl)",
    "ldl_f1_a1_b2": "식후2시간 혈당 (mg/dl)",
    "ldl_f1_a2_a": "최근 3개월 이내에 헤모글로빈A1c(HbA1c)검사 실시 여부 (0: 아니오, 1: 예)",
    "ldl_f1_a2_b1": "b-1.HbA1c (%)",
    "ldl_f1_a2_b2": "검사일: (YYYYMMDD)",
    "ldl_f1_b": "질병 및 상해 항목 b. 고혈압 (0: 미선택, 1: 선택)",
    "ldl_f1_c": "질병 및 상해 항목 c. 요로감염 (0: 미선택, 1: 선택)",
    "ldl_f1_d": "질병 및 상해 항목 d. 말초혈관질활 (0: 미선택, 1: 선택)",
    "ldl_f1_e": "질병 및 상해 항목 e. 하지마비 (0: 미선택, 1: 선택)",
    "ldl_f1_f": "질병 및 상해 항목 f. 사지마비 (0: 미선택, 1: 선택)",
    "ldl_f1_g": "질병 및 상해 항목 g. 편마비 (0: 미선택, 1: 선택)",
    "ldl_f1_h": "질병 및 상해 항목 h. 뇌성마비 (0: 미선택, 1: 선택)",
    "ldl_f1_i": "질병 및 상해 항목 i. 뇌혈관질환 (0: 미선택, 1: 선택)",
    "ldl_f1_j": "질병 및 상해 항목 j. 파킨슨병 (0: 미선택, 1: 선택)",
    "ldl_f1_k": "질병 및 상해 항목 k. 척수손상 (0: 미선택, 1: 선택)",
    "ldl_f1_l": "질병 및 상해 항목 l. 중증근무력증 및 기타 근신경 장애 (0: 미선택, 1: 선택)",
    "ldl_f1_m": "질병 및 상해 항목 m. 근육의 원발성 장애 (0: 미선택, 1: 선택)",
    "ldl_f1_n": "질병 및 상해 항목 n. 다발경화증(0: 미선택, 1: 선택)",
    "ldl_f1_o": "질병 및 상해 항목 o. 헌틴톤병(0: 미선택, 1: 선택)",
    "ldl_f1_p": "질병 및 상해 항목 p. 유전성 운동실조(0: 미선택, 1: 선택)",
    "ldl_f1_q": "질병 및 상해 항목 q. 척수성 근육위축 및 관련 증후군(0: 미선택, 1: 선택)",
    "ldl_f1_r": "질병 및 상해 항목 r. 달리 분류된 질환에서의 일차적으로 중추신경계통에 영향을 주는 전신 위축(0: 미선택, 1: 선택)",
    "ldl_f1_s": "질병 및 상해 항목 s. 진행성 핵상안근마비(0: 미선택, 1: 선택)",
    "ldl_f1_t": "질병 및 상해 항목 t. 중추 신경계통의 비정형바이러스 감염(0: 미선택, 1: 선택)",
    "ldl_f1_u": "질병 및 상해 항목 u. 아급성 괴사성 뇌병증(0: 미선택, 1: 선택)",
    "ldl_f1_v": "질병 및 상해 항목 v. 후천성 면역결핍증(0: 미선택, 1: 선택)",
    "ldl_f1_w": "질병 및 상해 항목 w. 치매(0: 미선택, 1: 선택)",
    "ldl_f1_x": "질병 및 상해 항목 x. 고지혈증(0: 미선택, 1: 선택)",
    "ldl_f1_y": "질병 및 상해 항목 y. 심부전(0: 미선택, 1: 선택)",
    "ldl_f1_z": "질병 및 상해 항목 z. 만성폐색성폐질환(0: 미선택, 1: 선택)",
    "ldl_f1_aa": "질병 및 상해 항목 aa. 천식(0: 미선택, 1: 선택)",
    "ldl_f1_ab": "질병 및 상해 항목 ab. 해당없음 (0: 미선택, 1: 선택)",
    "ldl_f2_a": "영양관련 장애 a. 콰시오르코르(E40) (0: 미선택, 1: 선택)",
    "ldl_f2_b": "영양관련 장애 b. 영양성 소모증(E41) (0: 미선택, 1: 선택)",
    "ldl_f2_c": "영양관련 장애 c. 소모성 콰시오르코르(E42) (0: 미선택, 1: 선택)",
    "ldl_f2_d": "영양관련 장애 d. 상세불명의 중증 단백질-에너지 영양실조(E43) (0: 미선택, 1: 선택)",
    "ldl_f2_e": "영양관련 장애 e. 중등도 및 경도의 단백질-에너지 영양실조(E44) (0: 미선택, 1: 선택)",
    "ldl_f2_f": "영양관련 장애 f. 단백질-에너지 영양실조로 인한 발육지연(E45) (0: 미선택, 1: 선택)",
    "ldl_f2_g": "영양관련 장애 g. 상세불명의 단백질-에너지 영양실조(E46) (0: 미선택, 1: 선택)",
    "ldl_f2_h": "영양관련 장애 h. 해당사항 없음 (0: 미선택, 1: 선택)",
    "ldl_g1_a": "건강상태 문제 상황 a.열 (0: 미선택, 1: 선택)",
    "ldl_g1_a1": "건강상태 문제 상황 a-1. 체온",
    "ldl_g1_a2": "건강상태 문제 상황 a-2. 발열 원인을 찾는 검사와 처치 시행 여부 (0: 아니오, 1: 예)",
    "ldl_g1_a3": "건강상태 문제 상황 a-3. 발열 일수",
    "ldl_g1_b": "건강상태 문제 상황 b. 탈수 (0: 미선택, 1: 선택)",
    "ldl_g1_c": "건강상태 문제 상황 c. 구토 (0: 미선택, 1: 선택)",
    "ldl_g1_d": "건강상태 문제 상황 d. 수술3개월 이내 루 관리 (0: 미선택, 1: 선택)",
    "ldl_g1_e": "건강상태 문제 상황 e. 출혈.감염 등의 문제로 인한 루 관리 (0: 미선택, 1: 선택)",
    "ldl_g1_f": "건강상태 문제 상황 f. 해당사항없음 (0: 미선택, 1: 선택)",
    "ldl_g1_g": "해당 없음",
    "ldl_g2_a": "통증 발생 빈도 (0: 없음, 1: 매일 아님, 2: 매일)",
    "ldl_g2_b": "해당 없음",
    "ldl_g2_b1": "시각통증등급(VAS) 점수 (0-10)",
    "ldl_g2_b2": "숫자통증등급(NRS) 점수 (0-10)",
    "ldl_g2_b3": "얼굴통증등급(FPS) 점수 (0-5)",
    "ldl_g2_c": "해당 없음",
    "ldl_g2_c1": "통증관련 치료 (0: 아니오, 1: 예)",
    "ldl_g2_c2": "암성통증 치료 (0: 아니오, 1: 예)",
    "ldl_g3_a": "낙상(지난 30일 이내에 낙상) (0: 아니오, 1: 예, 2: 확인불가)",
    "ldl_g3_b": "낙상(지난 31일에서 180일 사이 낙상) (0: 아니오, 1: 예, 2: 확인불가)",
    "ldl_g4": "말기질환 (0: 아니오, 1: 예)",
    "ldl_h1": "물이나 음식 삼키기 어려움 (0: 아니오, 1: 예)",
    "ldl_h21_a": "체중측정 여부 (0: 아니오, 1: 예)",
    "ldl_h21_b1": "체중(kg)",
    "ldl_h21_b2": "체중 측정일 (YYYYMMDD)",
    "ldl_h22": "체중감소 (0: 없음, 1: 있음, 2: 확인불가)",
    "ldl_h23_a": "키 측정 여부 (0: 아니오, 1: 예)",
    "ldl_h23_b1": "키(cm)",
    "ldl_h23_b2": "키 측정일 (YYYYMMDD)",
    "ldl_h3_a": "정맥영양 여부 (0: 아니오, 1: 예)",
    "ldl_h3_b": "해당 없음",
    "ldl_h3_b1": "경관영양 여부 (0: 아니오, 1: 예)",
    "ldl_h3_b2": "경관영양 실시일수",
    "ldl_h4_a": "정맥영양 상태 (0: 없음, 1: 1~25%, 2: 26~50%, 3: 51~75%, 4.76~100%)",
    "ldl_h4_b": "영양 형태 (0: 없음, 1: 1~500ml, 2: 501~1000ml, 3: 1001~1500ml, 4: 1501~2000ml, 5: 2001ml이상)",
    "ldl_i1_a1": "1단계 욕창 개수",
    "ldl_i1_a2": "2단계 욕창 개수",
    "ldl_i1_a3": "3단계 욕창 개수",
    "ldl_i1_a4": "4단계 욕창 개수",
    "ldl_i1_b1": "1단계 울혈성 또는 허혈성 궤양 개수",
    "ldl_i1_b2": "2단계 울혈성 또는 허혈성 궤양 개수",
    "ldl_i1_b3": "3단계 울혈성 또는 허혈성 궤양 개수",
    "ldl_i1_b4": "4단계 울혈성 또는 허혈성 궤양 개수",
    "ldl_i2_a": "새로운 욕창 발생 여부 (0: 아니오, 1: 예)",
    "ldl_i2_b": "욕창 발생일 (YYYYMMDD)",
    "ldl_i3": "지난 1년사이의 욕창 과거력 (0: 없음, 1: 있음, 2: 확인불가)",
    "ldl_i4_a": "피부기타문제 a. 2도 이상의 화상 (0: 미선택, 1: 선택)",
    "ldl_i4_b": "피부기타문제 b. 개방성 피부병변 (0: 미선택, 1: 선택)",
    "ldl_i4_b1": "해당 없음",
    "ldl_i4_b2": "해당 없음",
    "ldl_i4_c": "피부기타문제 c. 수술 창상 (0: 미선택, 1: 선택)",
    "ldl_i4_d": "피부기타문제 d. 발의 감염 (0: 미선택, 1: 선택)",
    "ldl_i4_e": "피부기타문제 e. 해당사항 없음 (0: 미선택, 1: 선택)",
    "ldl_i5_a": "피부문제처치 a. 압력을 줄여주는 도구 사용 (0: 미선택, 1: 선택)",
    "ldl_i5_b": "피부문제처치 b. 체위변경 (0: 미선택, 1: 선택)",
    "ldl_i5_c": "피부문제처치 c. 피부문제를 해결하기 위한 영양공급 (0: 미선택, 1: 선택)",
    "ldl_i5_d": "피부문제처치 d. 피부궤양 드레싱 (0: 미선택, 1: 선택)",
    "ldl_i5_d1": "d. 피부궤양 드레싱(발) (0: 아니오, 1: 예)",
    "ldl_i5_d2": "d. 피부궤양 드레싱(발 이외) (0: 아니오, 1: 예)",
    "ldl_i5_e": "피부문제처치 e. 피부궤양 이외의 드레싱 (0: 미선택, 1: 선택)",
    "ldl_i5_e1": "e. 피부궤양 이외의 드레싱(발) (0: 아니오, 1: 예)",
    "ldl_i5_e2": "e. 피부궤양 이외의 드레싱(발 이외) (0: 아니오, 1: 예)",
    "ldl_i5_f": "피부문제처치 f. 수술창상 치료 (0: 미선택, 1: 선택)",
    "ldl_i5_g": "피부문제처치 g. 화상관련 처치 (0: 미선택, 1: 선택)",
    "ldl_i5_h": "피부문제처치 h. 해당사항 없음 (0: 미선택, 1: 선택)",
    "ldl_j1": "인슐린 주사제 투여 일수 (0: 투여되지 않았거나, 투여되었지만 매일은 아님, 1: 매일 1회 투여, 2: 매일 2회 이상 투여)",
    "ldl_j2": "행동심리증상 약물 사용 (0: 아니오, 1: 예)",
    "ldl_j3": "치매관련 약제 복용 (0: 아니오, 1: 예)",
    "ldl_j4": "복용한 의약품 수 (0: 없음, 1: 5개 미만, 2: 5-9개, 3: 10-14개, 4: 15개 이상)",
    "ldl_k1_a": "특수처치 a. 정맥주사에 의한 투약 (0: 미선택, 1: 선택)",
    "ldl_k1_a1": "정맥주사 투여일수",
    "ldl_k1_b": "특수처치 b. 배뇨관련 루 관리 (0: 미선택, 1: 선택)",
    "ldl_k1_c": "특수처치 c. 배변관리 루 관리 (0: 미선택, 1: 선택)",
    "ldl_k1_d": "특수처치 d. 영양관련 루 관리 (0: 미선택, 1: 선택)",
    "ldl_k1_e": "특수처치 e. 산소요법 (0: 미선택, 1: 선택)",
    "ldl_k1_e1": "산소포화도 (%)",
    "ldl_k1_e2": "산소투여 일수",
    "ldl_k1_f": "특수처치 f. 하기도 증기흡입 치료 (0: 미선택, 1: 선택)",
    "ldl_k1_g": "특수처치 g. 흡인 (0: 미선택, 1: 선택)",
    "ldl_k1_h": "특수처치 h. 기관절개관 관리 (0: 미선택, 1: 선택)",
    "ldl_k1_i": "특수처치 i. 인공호흡기 (0: 미선택, 1: 선택)",
    "ldl_k1_i1": "개인용 인공호흡기 (0: 아니오, 1: 예)",
    "ldl_k1_i2": "병원용 인공호흡기 (0: 아니오, 1: 예)",
    "ldl_k1_j": "특수처치 j. 중심정맥영양 (0: 미선택, 1: 선택)",
    "ldl_k1_j1": "해당 없음",
    "ldl_k1_j2": "해당 없음",
    "ldl_k1_k": "특수처치 k. 해당사항 없음 (0: 미선택, 1: 선택)",
    "ldl_k1_l": "해당 없음",
    "ldl_k2": "전문재활치료 실시일수 (0-7)",
}

ldl_keys = [
    "ldl_a10_a",
    "ldl_a10_b",
    "ldl_a10_c",
    "ldl_a10_d",
    "ldl_a11",
    "ldl_a12_a",
    "ldl_a12_b1",
    "ldl_a12_b2",
    "ldl_a12_b3",
    "ldl_a12_b4",
    "ldl_a12_b5",
    "ldl_a12_b6",
    "ldl_a12_b7",
    "ldl_a12_b8",
    "ldl_a13",
    "ldl_a14_a",
    "ldl_a14_b",
    "ldl_a14_c",
    "ldl_a14_d",
    "ldl_a14_e",
    "ldl_a14_f",
    "ldl_a14_g",
    "ldl_b1",
    "ldl_b2",
    "ldl_c1",
    "ldl_c2",
    "ldl_c3",
    "ldl_c4",
    "ldl_c5_a",
    "ldl_c5_b",
    "ldl_c5_c",
    "ldl_c5_d",
    "ldl_c5_e",
    "ldl_c5_f",
    "ldl_c5_g",
    "ldl_c5_h",
    "ldl_c5_i",
    "ldl_c5_j",
    "ldl_c5_k",
    "ldl_c5_l",
    "ldl_c5_m",
    "ldl_c5_n",
    "ldl_c6_a",
    "ldl_c6_b1",
    "ldl_c6_b2",
    "ldl_c7_a",
    "ldl_c7_b1",
    "ldl_c7_b2",
    "ldl_c7_c",
    "ldl_c7_d1",
    "ldl_c7_d2",
    "ldl_d1",
    "ldl_d2",
    "ldl_d3",
    "ldl_d4",
    "ldl_d5",
    "ldl_d6",
    "ldl_d7",
    "ldl_d8",
    "ldl_d9",
    "ldl_d10",
    "ldl_d11",
    "ldl_d12_a",
    "ldl_d12_b",
    "ldl_d12_c",
    "ldl_e1",
    "ldl_e2",
    "ldl_e3_a",
    "ldl_e3_b",
    "ldl_e3_c",
    "ldl_e3_d",
    "ldl_e3_e",
    "ldl_e3_f",
    "ldl_e3_g",
    "ldl_e3_g1",
    "ldl_e3_g1_1",
    "ldl_e3_g1_2",
    "ldl_e3_g2_1",
    "ldl_e3_g2_2",
    "ldl_e3_g3_1",
    "ldl_e3_g3_2",
    "ldl_e3_g4_1",
    "ldl_e3_g4_2",
    "ldl_e3_g5_1",
    "ldl_e3_g5_2",
    "ldl_e3_g6_1",
    "ldl_e3_g6_2",
    "ldl_e3_g7_1",
    "ldl_e3_g7_2",
    "ldl_e3_g8_1",
    "ldl_e3_g8_2",
    "ldl_e3_g9_1",
    "ldl_e3_g9_2",
    "ldl_e3_g10_1",
    "ldl_e3_g10_2",
    "ldl_e3_g11",
    "ldl_e3_h",
    "ldl_e4",
    "ldl_e4_a",
    "ldl_e4_b",
    "ldl_f1_a",
    "ldl_f1_a1_a",
    "ldl_f1_a1_b1",
    "ldl_f1_a1_b2",
    "ldl_f1_a2_a",
    "ldl_f1_a2_b1",
    "ldl_f1_a2_b2",
    "ldl_f1_b",
    "ldl_f1_c",
    "ldl_f1_d",
    "ldl_f1_e",
    "ldl_f1_f",
    "ldl_f1_g",
    "ldl_f1_h",
    "ldl_f1_i",
    "ldl_f1_j",
    "ldl_f1_k",
    "ldl_f1_l",
    "ldl_f1_m",
    "ldl_f1_n",
    "ldl_f1_o",
    "ldl_f1_p",
    "ldl_f1_q",
    "ldl_f1_r",
    "ldl_f1_s",
    "ldl_f1_t",
    "ldl_f1_u",
    "ldl_f1_v",
    "ldl_f1_w",
    "ldl_f1_x",
    "ldl_f1_y",
    "ldl_f1_z",
    "ldl_f1_aa",
    "ldl_f1_ab",
    "ldl_f2_a",
    "ldl_f2_b",
    "ldl_f2_c",
    "ldl_f2_d",
    "ldl_f2_e",
    "ldl_f2_f",
    "ldl_f2_g",
    "ldl_f2_h",
    "ldl_g1_a",
    "ldl_g1_a1",
    "ldl_g1_a2",
    "ldl_g1_a3",
    "ldl_g1_b",
    "ldl_g1_c",
    "ldl_g1_d",
    "ldl_g1_e",
    "ldl_g1_f",
    "ldl_g1_g",
    "ldl_g2_a",
    "ldl_g2_b",
    "ldl_g2_b1",
    "ldl_g2_b2",
    "ldl_g2_b3",
    "ldl_g2_c",
    "ldl_g2_c1",
    "ldl_g2_c2",
    "ldl_g3_a",
    "ldl_g3_b",
    "ldl_g4",
    "ldl_h1",
    "ldl_h21_a",
    "ldl_h21_b1",
    "ldl_h21_b2",
    "ldl_h22",
    "ldl_h23_a",
    "ldl_h23_b1",
    "ldl_h23_b2",
    "ldl_h3_a",
    "ldl_h3_b",
    "ldl_h3_b1",
    "ldl_h3_b2",
    "ldl_h4_a",
    "ldl_h4_b",
    "ldl_i1_a1",
    "ldl_i1_a2",
    "ldl_i1_a3",
    "ldl_i1_a4",
    "ldl_i1_b1",
    "ldl_i1_b2",
    "ldl_i1_b3",
    "ldl_i1_b4",
    "ldl_i2_a",
    "ldl_i2_b",
    "ldl_i3",
    "ldl_i4_a",
    "ldl_i4_b",
    "ldl_i4_b1",
    "ldl_i4_b2",
    "ldl_i4_c",
    "ldl_i4_d",
    "ldl_i4_e",
    "ldl_i5_a",
    "ldl_i5_b",
    "ldl_i5_c",
    "ldl_i5_d",
    "ldl_i5_d1",
    "ldl_i5_d2",
    "ldl_i5_e",
    "ldl_i5_e1",
    "ldl_i5_e2",
    "ldl_i5_f",
    "ldl_i5_g",
    "ldl_i5_h",
    "ldl_j1",
    "ldl_j2",
    "ldl_j3",
    "ldl_j4",
    "ldl_k1_a",
    "ldl_k1_a1",
    "ldl_k1_b",
    "ldl_k1_c",
    "ldl_k1_d",
    "ldl_k1_e",
    "ldl_k1_e1",
    "ldl_k1_e2",
    "ldl_k1_f",
    "ldl_k1_g",
    "ldl_k1_h",
    "ldl_k1_i",
    "ldl_k1_i1",
    "ldl_k1_i2",
    "ldl_k1_j",
    "ldl_k1_j1",
    "ldl_k1_j2",
    "ldl_k1_k",
    "ldl_k1_l",
    "ldl_k2",
]

ldl_item_dict = {
    "입원군_최고도": "ldl_etc4",
    "입원군_고도": "ldl_etc4",
    "입원군_중도": "ldl_etc4",
    "입원군_경도": "ldl_etc4",
    "입원군_선택입원": "ldl_etc4",
    "ADL": "ldl_adl",
    "장기요양등급": "ldl_a12_a",
    "혼수": "ldl_b1",
    "섬망": "ldl_b2",
    "망상": "ldl_c5_a",
    "단기기억력장애": "ldl_c1",
    "인식기술": "ldl_c2",
    "이해시키는능력": "ldl_c3",
    "의사표현": "ldl_c4",
}
